
function [lon_soc,lat_soc,lonvec,latvec,sss,index, ...
	sst,netheat,eminusp,taux,tauy]=loadsocyear(year,invadj);

% function [lon_soc,lat_soc,lonvec,latvec,sss,index, ...
%	sst,netheat,eminusp,taux,tauy]=loadsocyear(year,invadj);
%
% load a year (=80 through 97) of monthly
% observations from the COADS fields.  Output
% is mean + anomaly.  For the climatology alone
% (mean of 1980-1993), input a negative number for "year".
% invadj=[] or 0: unadjusted.  =1: adjusted.

% invadj: if not present, the unadjusted components will
%   be returned.  If invadj==1, the individual heat flux
%   components will be adjusted using the Grist and Josey
%   (J.Clim. 16 (10), 2003) coefficients.
%   if invadj is a vector (length 4), it is used as
%   the adjustment coefficients for latent, sensible,
%   longwave, and shortwave (respectively).

if ~exist('invadj')
    invadj=0;
end;
if (invadj==1)
    xcoef=[1.19 1.07 1.09 0.94];
elseif (length(invadj)==4)
    xcoef=invadj;
    invadj=1;
end;


if (year<0 & invadj==0)
    disp('Loading unadjusted monthly means, SOC/COADS')
    load soc_mean
%%% NOTE: the following lines were added after running
% this routine as written to construct and calculate
% the adjusted means from the full anomaly fields,
% using Grist and Josey solution 3 coefficients.
% By saving the adjusted field after running it once,
% and loading it here rather than recalculating it,
% this code is much faster.  However, the following
% lines could be commented out to recalculate the
% GJ03 solution 3 monthly means from the unadjusted fields.
elseif (year<0 & xcoef(1)==1.19 & xcoef(2)==1.07 & ...
        xcoef(3)==1.09 & xcoef(4)==0.94);
    load soc_mean_invadj_gj03
elseif (year>1997 | (year<1980 & year>1900) | ...
        (year<80 & year>0) | (year>97 & year<1900))
    % year must be in the range 1980-1997 / 80-97
  disp('SOC/COADS only contains values for Jan 1980-Dec.1997.');
  return;
else
    
if (year>1900) year=year-1900; end;
if (year>0)
    fprintf('Loading SOC/COADS monthly fields for %d.\n',1900+year);
else
    % loading the individual components; 
    % mean to be calculated after inverse adjustment
    disp('Loading SOC/COADS monthly fields.');
end;

direc='/phod007/lumpkin/soc_invadj/unadjusted_components/';

lat_soc=(-84.5:84.5)';
lon_soc=[40.5:180 -179.5:39.5]';
t_soc=(80+.5/12:1/12:97+11.5/12)';  % 19xx  [years]
if (invadj>0)
    disp('Adjusting heat flux components.')
    eval(['load ',direc,'alatim alatim']);  % latent
    eval(['load ',direc,'asenim asenim']);  % sensible
    eval(['load ',direc,'alwim alwim']);    % longwave
    eval(['load ',direc,'aswim aswim']);    % shortwave
    anetim=NaN*ones(size(alatim));
    anetim=xcoef(1)*alatim + xcoef(2)*asenim + ...
        xcoef(3)*alwim + xcoef(4)*aswim;
    clear alatim asenim alwim aswim;
else % unadjusted - simply load net monthly 
    eval(['load ',direc,'anetim anetim']);    % net 
end;
eval(['load ',direc,'asstim asstim']);  % SST
eval(['load ',direc,'ataeim ataeim']);  % tau_x
eval(['load ',direc,'atanim atanim']);  % tau_y
eval(['load ',direc,'aempim aempimmmo']);  % E-P

% convert E-P from mm/month to m/s
aempimmmo=aempimmmo/30.44/24/3600/1e3;

% truncate to desired year
if (year>0)
    q=find(t_soc>=year & t_soc<year+1);
    anetim=anetim(:,:,q);
    asstim=asstim(:,:,q);
    ataeim=ataeim(:,:,q);
    atanim=atanim(:,:,q);
    aempimmmo=aempimmmo(:,:,q);
    t_soc=t_soc(q);
else
    for j=1:12;
        q=j:12:size(anetim,3);
        anetim(:,:,j)=mean(anetim(:,:,q),3);
        asstim(:,:,j)=mean(asstim(:,:,q),3);
        ataeim(:,:,j)=mean(ataeim(:,:,q),3);
        atanim(:,:,j)=mean(atanim(:,:,q),3);
        aempimmmo(:,:,j)=mean(aempimmmo(:,:,q),3);
    end;
    anetim=anetim(:,:,1:12);
    asstim=asstim(:,:,1:12);
    ataeim=ataeim(:,:,1:12);
    aempimmmo=aempimmmo(:,:,1:12);
    t_soc=1:12;
end;

% break at +-180 longitude
sst=NaN*ones(size(asstim));
net=sst; taux=sst; tauy=sst; emp=sst;
[lon_soc,ind]=sort(lon_soc);
for i=1:length(t_soc)
    sst(:,:,i)=asstim(:,ind,i);
    net(:,:,i)=anetim(:,ind,i);
    taux(:,:,i)=ataeim(:,ind,i);
    tauy(:,:,i)=atanim(:,ind,i);
    emp(:,:,i)=aempimmmo(:,ind,i);
end;
clear a*im i
asstim=sst;anetim=net;ataeim=taux;atanim=tauy;aempimmmo=emp;

latvec=lat_soc*ones(1,length(lon_soc));
lonvec=ones(length(lat_soc),1)*lon_soc';
index=1:length(latvec)*length(lonvec);

% find where no data exists on lon,lat grid.
% Note: due to changing ice edge, some grid
% points may only have summer values.
qnetcm2=anetim;
q=find(isnan(qnetcm2));
qnetcm2(q)=999;
q=find(sum(qnetcm2,3)<12*999);
latvec=latvec(q);
lonvec=lonvec(q);
index=index(q);
netheat=NaN*ones(12,length(q));
sst=netheat;eminusp=netheat;
taux=netheat;tauy=netheat;
for i=1:12;
  ff=anetim(:,:,i);
  netheat(i,:)=(ff(q))';
  ff=asstim(:,:,i);
  sst(i,:)=(ff(q))';
  ff=ataeim(:,:,i);
  taux(i,:)=(ff(q))';
  ff=atanim(:,:,i);
  tauy(i,:)=(ff(q))';
  ff=aempimmmo(:,:,i);
  eminusp(i,:)=(ff(q))';
end;
latvec=latvec';
lonvec=lonvec';

load soc_mean sss

end; % if (year<0 & invadj==0)
