

% makesocmean - uses loadsocyear code, loads all years,
%   and calculates the overall monthly means (1980-1997).

% function [lon_soc,lat_soc,lonvec,latvec,sss,index, ...
%	sst,netheat,eminusp,taux,tauy]=loadsocyear(year);
%
% load a year (=80 through 97) of monthly
% observations from the SOC/COADS fields.  Output
% is mean + anomaly.  For the climatology alone,
% input a negative number for "year".

year=-99;

direc='/phod007/lumpkin/soc_invadj/unadjusted_components/';

lat_soc=(-84.5:84.5)';
lon_soc=[40.5:180 -179.5:39.5]';
t_soc=(1980+.5/12:1/12:1997+11.5/12)';
eval(['load ',direc,'alatim alatim']);  % latent
eval(['load ',direc,'asenim asenim']);  % sensible
eval(['load ',direc,'alwim alwim']);    % longwave
eval(['load ',direc,'aswim aswim']);    % shortwave
eval(['load ',direc,'anetim anetim']);    % net (sum of lt,se,sw,lw)
eval(['load ',direc,'asstim asstim']);  % SST
eval(['load ',direc,'ataeim ataeim']);  % tau_x
eval(['load ',direc,'atanim atanim']);  % tau_y
eval(['load ',direc,'aempim aempimmmo']);  % E-P

% convert E-P from mm/month to m/s
aempimmmo=aempimmmo/30.44/24/3600/1e3;

% truncate to desired year
if (year>0)
    q=find(t_soc>=year & t_soc<year+1);
    alatim=alatim(:,:,q);
    asensim=asenim(:,:,q);
    alwim=alwim(:,:,q);
    aswim=aswim(:,:,q);
    anetim=anetim(:,:,q);
    asstim=asstim(:,:,q);
    ataeim=ataeim(:,:,q);
    atanim=atanim(:,:,q);
    aempimmmo=aempimmmo(:,:,q);
    t_soc=t_soc(q);
else
    t_soc=t_soc-floor(t_soc); % fractional year
    sst=NaN*ones(size(asstim,1),size(asstim,2),12);
    net=sst; taux=sst; tauy=sst; emp=sst;
    latnt=sst;sens=sst;lngw=sst;shtw=sst;
    for i=1:12;
        q=find(t_soc==t_soc(i));
        net(:,:,i)=mean(anetim(:,:,q),3);
        sst(:,:,i)=mean(asstim(:,:,q),3);
        taux(:,:,i)=mean(ataeim(:,:,q),3);
        tauy(:,:,i)=mean(atanim(:,:,q),3);
        emp(:,:,i)=mean(aempimmmo(:,:,q),3);
        latnt(:,:,i)=mean(alatim(:,:,q),3);
        sens(:,:,i)=mean(asenim(:,:,q),3);
        lngw(:,:,i)=mean(alwim(:,:,q),3);
        shtw(:,:,i)=mean(aswim(:,:,q),3);
    end;
    t_soc=t_soc(1:12);
    asstim=sst;anetim=net;ataeim=taux;atanim=tauy;aempimmmo=emp;
    alatim=latnt;asenim=sens;alwim=lngw;aswim=shtw;
end;

% break at +-180 longitude
sst=NaN*ones(size(asstim));
net=sst; taux=sst; tauy=sst; emp=sst;
latnt=sst;sens=sst;lngw=sst;shtw=sst;
[lon_soc,ind]=sort(lon_soc);
for i=1:length(t_soc)
    sst(:,:,i)=asstim(:,ind,i);
    net(:,:,i)=anetim(:,ind,i);
    taux(:,:,i)=ataeim(:,ind,i);
    tauy(:,:,i)=atanim(:,ind,i);
    emp(:,:,i)=aempimmmo(:,ind,i);
    latnt(:,:,i)=alatim(:,ind,i);
    sens(:,:,i)=asenim(:,ind,i);
    lngw(:,:,i)=alwim(:,ind,i);
    shtw(:,:,i)=aswim(:,ind,i);
end;
clear a*im i
asstim=sst;anetim=net;ataeim=taux;atanim=tauy;aempimmmo=emp;
alatim=latnt;asenim=sens;alwim=lngw;aswim=shtw;

latvec=lat_soc*ones(1,length(lon_soc));
lonvec=ones(length(lat_soc),1)*lon_soc';
index=1:length(latvec)*length(lonvec);

% find where no data exists on lon,lat grid.
% Note: due to changing ice edge, some grid
% points may only have summer values.
qnetcm2=anetim;
q=find(isnan(qnetcm2));
qnetcm2(q)=999;
q=find(sum(qnetcm2,3)<12*999);
latvec=latvec(q);
lonvec=lonvec(q);
index=index(q);
netheat=NaN*ones(12,length(q));
sst=netheat;eminusp=netheat;
taux=netheat;tauy=netheat;
latnt=netheat;sens=netheat;
lngw=netheat;shtw=netheat;
for i=1:12;
  ff=anetim(:,:,i);
  netheat(i,:)=(ff(q))';
  ff=asstim(:,:,i);
  sst(i,:)=(ff(q))';
  ff=ataeim(:,:,i);
  taux(i,:)=(ff(q))';
  ff=atanim(:,:,i);
  tauy(i,:)=(ff(q))';
  ff=aempimmmo(:,:,i);
  eminusp(i,:)=(ff(q))';
  ff=alatim(:,:,i);
  latnt(i,:)=(ff(q))';
  ff=asenim(:,:,i);
  sens(i,:)=(ff(q))';
  ff=alwim(:,:,i);
  lngw(i,:)=(ff(q))';
  ff=aswim(:,:,i);
  shtw(i,:)=(ff(q))';
end;
latvec=latvec';
lonvec=lonvec';

% Sea surface salinity: use monthly mean Levitus94
% values as in UWM/COADS 
sss=NaN*ones(size(sst));
load /phod007/lumpkin/coads/sss_levitus94
% loop through, assigning matching values
for i=1:length(lonvec);
    fprintf('  %d of %d\n',i,length(lonvec));
    q=find(latvec_coads==latvec(i) & ...
        lonvec_coads==lonvec(i));
    if ~length(q) keyboard; end;
    sss(:,i)=sss_coads(:,q);
end;

save soc_mean lon_soc lat_soc lonvec latvec sss index  ...
	sst netheat eminusp taux tauy latnt sens lngw shtw;